@@ -54,10 +54,26 @@ Catalyst::Engine::Apache2::MP19 - Catalyst Apache2 mod_perl 1.99x Engine
         </Location>
         
         # Make sure to let Apache handle your static files
-        # (And remember to remove the Static::Simple plugin in production)
+        # (It is not necessary to remove the Static::Simple plugin 
+        # in production; Apache will bypass Static::Simple if
+        # configured in this way)
+
         <Location /static>
             SetHandler          default-handler
-        </Location>   
+        </Location>
+ 
+        # If not running at a root location in a VirtualHost,
+        # you'll probably need to set an Alias to the location
+        # of your static files, and allow access to this location:
+
+        Alias /myapp/static /filesystem/path/to/MyApp/root/static
+        <Directory /filesystem/path/to/MyApp/root/static>
+            allow from all
+        </Directory>
+        <Location /myapp/static>
+            SetHandler default-handler
+        </Location>
+
     </VirtualHost>
 
 =head1 DESCRIPTION
